@@ -1,6 +1,6 @@
 package Catmandu::XML::Transformer;
 
-our $VERSION = '0.15';
+our $VERSION = '0.17';
 
 use Catmandu::Sane;
 use Moo;
@@ -21,7 +21,7 @@ has stylesheet => (
 
 has output_format => (
     is     => 'ro', 
-    coerce => sub { lc $_[0] }
+    coerce => sub { defined $_[0] ? lc $_[0] : undef }
 );
 
 has process => (
